@@ -1,7 +1,7 @@
+import quopri
 import re
 import sys
 import unicodedata
-import quopri
 
 from unstructured.nlp.patterns import UNICODE_BULLETS_RE
 
@@ -23,7 +23,7 @@ def clean_bullets(text) -> str:
 
 def clean_ordered_bullets(text) -> str:
     """Cleans the start of bulleted text sections up to three “sub-section”
-    bullets accounting numeric and alpha-numeric types.
+    bullets accounting numeric and alphanumeric types.
 
     Example
     -------
@@ -149,7 +149,7 @@ def clean_prefix(text: str, pattern: str, ignore_case: bool = False, strip: bool
     strip: If True, removes leading whitespace from the cleaned string.
     """
     flags = re.IGNORECASE if ignore_case else 0
-    clean_text = re.sub(r"^{0}".format(pattern), "", text, flags=flags)
+    clean_text = re.sub(rf"^{pattern}", "", text, flags=flags)
     clean_text = clean_text.lstrip() if strip else clean_text
     return clean_text
 
@@ -166,7 +166,7 @@ def clean_postfix(text: str, pattern: str, ignore_case: bool = False, strip: boo
     strip: If True, removes trailing whitespace from the cleaned string.
     """
     flags = re.IGNORECASE if ignore_case else 0
-    clean_text = re.sub(r"{0}$".format(pattern), "", text, flags=flags)
+    clean_text = re.sub(rf"{pattern}$", "", text, flags=flags)
     clean_text = clean_text.rstrip() if strip else clean_text
     return clean_text
 
